@@ -49,11 +49,13 @@ class ApplyUpgrade:
         # pipe size limit (unlikely but...)
         stdout = ""
         while p.poll() is None:
-            # send alive ping
+            # FIXME: dbus is history soon
             if config.dbus_service:
                 config.dbus_service.UpdateProgress(-1, -1)
+            # send alive ping
             if getattr(config, "machine_readable", False):
-                print("SPINNER:"+json.dumps({}))
+                print(json.dumps({"type": "spinner",
+                                  "msg": "Applying update"}))
             time.sleep(0.1)
             if select.select([p.stdout.fileno()], [], []) != ([], [], []):
                 stdout += p.stdout.read().decode("utf-8", errors="replace")
